==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/CacheRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin

import com.pulumi.azurenative.containerregistry.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.containerregistry.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [CacheRule].
 */
@PulumiTagMarker
public class CacheRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: CacheRuleArgs = CacheRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend CacheRuleArgsBuilder.() -> Unit) {
        val builder = CacheRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): CacheRule {
        val builtJavaResource =
            com.pulumi.azurenative.containerregistry.CacheRule(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return CacheRule(builtJavaResource)
    }
}

/**
 * An object that represents a cache rule for a container registry.
 * Azure REST API version: 2023-01-01-preview.
 * Other available API versions: 2023-06-01-preview, 2023-07-01, 2023-08-01-preview, 2023-11-01-preview.
 * ## Example Usage
 * ### CacheRuleCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var cacheRule = new AzureNative.ContainerRegistry.CacheRule("cacheRule", new()
 *     {
 *         CacheRuleName = "myCacheRule",
 *         CredentialSetResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myResourceGroup/providers/Microsoft.ContainerRegistry/registries/myRegistry/credentialSets/myCredentialSet",
 *         RegistryName = "myRegistry",
 *         ResourceGroupName = "myResourceGroup",
 *         SourceRepository = "docker.io/library/hello-world",
 *         TargetRepository = "cached-docker-hub/hello-world",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/containerregistry/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := containerregistry.NewCacheRule(ctx, "cacheRule", &containerregistry.CacheRuleArgs{
 * 			CacheRuleName:           pulumi.String("myCacheRule"),
 * 			CredentialSetResourceId: pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myResourceGroup/providers/Microsoft.ContainerRegistry/registries/myRegistry/credentialSets/myCredentialSet"),
 * 			RegistryName:            pulumi.String("myRegistry"),
 * 			ResourceGroupName:       pulumi.String("myResourceGroup"),
 * 			SourceRepository:        pulumi.String("docker.io/library/hello-world"),
 * 			TargetRepository:        pulumi.String("cached-docker-hub/hello-world"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.containerregistry.CacheRule;
 * import com.pulumi.azurenative.containerregistry.CacheRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var cacheRule = new CacheRule("cacheRule", CacheRuleArgs.builder()
 *             .cacheRuleName("myCacheRule")
 *             .credentialSetResourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myResourceGroup/providers/Microsoft.ContainerRegistry/registries/myRegistry/credentialSets/myCredentialSet")
 *             .registryName("myRegistry")
 *             .resourceGroupName("myResourceGroup")
 *             .sourceRepository("docker.io/library/hello-world")
 *             .targetRepository("cached-docker-hub/hello-world")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:containerregistry:CacheRule myCacheRule /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ContainerRegistry/registries/{registryName}/cacheRules/{cacheRuleName}
 * ```
 */
public class CacheRule internal constructor(
    override val javaResource: com.pulumi.azurenative.containerregistry.CacheRule,
) : KotlinCustomResource(javaResource, CacheRuleMapper) {
    /**
     * The creation date of the cache rule.
     */
    public val creationDate: Output<String>
        get() = javaResource.creationDate().applyValue({ args0 -> args0 })

    /**
     * The ARM resource ID of the credential store which is associated with the cache rule.
     */
    public val credentialSetResourceId: Output<String>?
        get() = javaResource.credentialSetResourceId().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provisioning state of the resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Source repository pulled from upstream.
     */
    public val sourceRepository: Output<String>?
        get() = javaResource.sourceRepository().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Target repository specified in docker pull command.
     * Eg: docker pull myregistry.azurecr.io/{targetRepository}:{tag}
     */
    public val targetRepository: Output<String>?
        get() = javaResource.targetRepository().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The type of the resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object CacheRuleMapper : ResourceMapper<CacheRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.containerregistry.CacheRule::class == javaResource::class

    override fun map(javaResource: Resource): CacheRule = CacheRule(
        javaResource as
            com.pulumi.azurenative.containerregistry.CacheRule,
    )
}

/**
 * @see [CacheRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [CacheRule].
 */
public suspend fun cacheRule(name: String, block: suspend CacheRuleResourceBuilder.() -> Unit):
    CacheRule {
    val builder = CacheRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [CacheRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun cacheRule(name: String): CacheRule {
    val builder = CacheRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/CacheRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin

import com.pulumi.azurenative.containerregistry.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.containerregistry.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [CacheRule].
 */
@PulumiTagMarker
public class CacheRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: CacheRuleArgs = CacheRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend CacheRuleArgsBuilder.() -> Unit) {
        val builder = CacheRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): CacheRule {
        val builtJavaResource =
            com.pulumi.azurenative.containerregistry.CacheRule(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return CacheRule(builtJavaResource)
    }
}

/**
 * An object that represents a cache rule for a container registry.
 * Azure REST API version: 2023-01-01-preview.
 * Other available API versions: 2023-06-01-preview, 2023-07-01, 2023-08-01-preview, 2023-11-01-preview.
 * ## Example Usage
 * ### CacheRuleCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var cacheRule = new AzureNative.ContainerRegistry.CacheRule("cacheRule", new()
 *     {
 *         CacheRuleName = "myCacheRule",
 *         CredentialSetResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myResourceGroup/providers/Microsoft.ContainerRegistry/registries/myRegistry/credentialSets/myCredentialSet",
 *         RegistryName = "myRegistry",
 *         ResourceGroupName = "myResourceGroup",
 *         SourceRepository = "docker.io/library/hello-world",
 *         TargetRepository = "cached-docker-hub/hello-world",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/containerregistry/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := containerregistry.NewCacheRule(ctx, "cacheRule", &containerregistry.CacheRuleArgs{
 * 			CacheRuleName:           pulumi.String("myCacheRule"),
 * 			CredentialSetResourceId: pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myResourceGroup/providers/Microsoft.ContainerRegistry/registries/myRegistry/credentialSets/myCredentialSet"),
 * 			RegistryName:            pulumi.String("myRegistry"),
 * 			ResourceGroupName:       pulumi.String("myResourceGroup"),
 * 			SourceRepository:        pulumi.String("docker.io/library/hello-world"),
 * 			TargetRepository:        pulumi.String("cached-docker-hub/hello-world"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.containerregistry.CacheRule;
 * import com.pulumi.azurenative.containerregistry.CacheRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var cacheRule = new CacheRule("cacheRule", CacheRuleArgs.builder()
 *             .cacheRuleName("myCacheRule")
 *             .credentialSetResourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myResourceGroup/providers/Microsoft.ContainerRegistry/registries/myRegistry/credentialSets/myCredentialSet")
 *             .registryName("myRegistry")
 *             .resourceGroupName("myResourceGroup")
 *             .sourceRepository("docker.io/library/hello-world")
 *             .targetRepository("cached-docker-hub/hello-world")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:containerregistry:CacheRule myCacheRule /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ContainerRegistry/registries/{registryName}/cacheRules/{cacheRuleName}
 * ```
 */
public class CacheRule internal constructor(
    override val javaResource: com.pulumi.azurenative.containerregistry.CacheRule,
) : KotlinCustomResource(javaResource, CacheRuleMapper) {
    /**
     * The creation date of the cache rule.
     */
    public val creationDate: Output<String>
        get() = javaResource.creationDate().applyValue({ args0 -> args0 })

    /**
     * The ARM resource ID of the credential store which is associated with the cache rule.
     */
    public val credentialSetResourceId: Output<String>?
        get() = javaResource.credentialSetResourceId().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provisioning state of the resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Source repository pulled from upstream.
     */
    public val sourceRepository: Output<String>?
        get() = javaResource.sourceRepository().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Target repository specified in docker pull command.
     * Eg: docker pull myregistry.azurecr.io/{targetRepository}:{tag}
     */
    public val targetRepository: Output<String>?
        get() = javaResource.targetRepository().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The type of the resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object CacheRuleMapper : ResourceMapper<CacheRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.containerregistry.CacheRule::class == javaResource::class

    override fun map(javaResource: Resource): CacheRule = CacheRule(
        javaResource as
            com.pulumi.azurenative.containerregistry.CacheRule,
    )
}

/**
 * @see [CacheRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [CacheRule].
 */
public suspend fun cacheRule(name: String, block: suspend CacheRuleResourceBuilder.() -> Unit):
    CacheRule {
    val builder = CacheRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [CacheRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun cacheRule(name: String): CacheRule {
    val builder = CacheRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}
